import sys;from sys import stdin,stdout
终端输入=stdin
终端输出=stdout
错误输出=sys.stderr
class 终端(object):
    def __init__(self):
        self.终端输入=终端输入
        self.终端输出=终端输出
        self.错误输出中心=错误输出
    def 打印(self,*args):
        print(*args)
    def 输入一行(self,提示):
        return input(提示)
    def 错误输出(self,*args):
        for i in args:
            self.错误输出中心.write(i)
            self.错误输出中心.write('\n')
            self.错误输出中心.flush()
    def 刷新(self,要刷新的内容=[stdin,stdout,错误输出]):
        for i in 要刷新的内容:
            i.flush()



from tkinter import *;import tkinter;from tkinter import messagebox,ttk,filedialog
class 窗口(tkinter.Tk):
    def __init__(self):
        Tk.__init__(self)
    主循环=Tk.mainloop
    标题=Tk.title
    图标=Tk.iconbitmap
    大小和位置=Tk.geometry
    属性=Tk.attributes
    协议=Tk.protocol
class 标签(Label):
    def __init__(self,容器,文本='',图片=None,字体=None):
        Label.__init__(master=容器,text=文本,image=图片,font=字体)
    居中显示=Label.pack
    在指定行显示=Label.grid
    设置xy显示=Label.place
class 按钮(Label):
    def __init__(self,容器,文本='',图片=None,字体=None):
        Button.__init__(master=容器,text=文本,image=图片,font=字体)
    居中显示=Button.pack
    在指定行显示=Button.grid
    设置xy显示=Button.place



def 打开(名称,编码="utf-8",方式="w+"):
    方式2=方式.replace("写+","w+").replace("读",'r').replace("写",'w').replace("文本",'t').replace("读+",'r+')
    file=open(名称,方式2,encoding=编码)
    return file
def 关闭(文件):
    文件.close()
def 写入(文件,文本=''):
    文件.write(文本)
def 读行(文件):
    w=文件.readline()
    return w
def 读所有行(文件):
    w=文件.readlines()
    return w
def 读取(文件):
    w=文件.read()
    return w



from setuptools import setup

setup(
    name='Pycn',
    version='0.0.1',
    packages=['Pycn'],
    url='https://github.com/',
    license='MIT License',
    author='Ruoyu Wang',
    author_email='wangkang@139.com',
    description='王若宇出品的中文python库，用中文写Python~初来乍到，持续更新。'
)
